Onegov Winterthur
=================

OneGov Cloud for the City of Winterthur

Run the Tests
-------------
    
Install tox and run it::

    pip install tox
    tox

Limit the tests to a specific python version::

    tox -e py27

Conventions
-----------

Onegov Winterthur follows PEP8 as close as possible. To test for it run::

    tox -e pep8

Onegov Winterthur uses `Semantic Versioning <http://semver.org/>`_

Build Status
------------

.. image:: https://travis-ci.org/OneGov/onegov.winterthur.png
  :target: https://travis-ci.org/OneGov/onegov.winterthur
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/OneGov/onegov.winterthur/badge.png?branch=master
  :target: https://coveralls.io/r/OneGov/onegov.winterthur?branch=master
  :alt: Project Coverage

Latest PyPI Release
-------------------

.. image:: https://badge.fury.io/py/onegov.winterthur.svg
    :target: https://badge.fury.io/py/onegov.winterthur
    :alt: Latest PyPI Release

License
-------
onegov.winterthur is released under GPLv2
